package com.jxdinfo.hussar.core.config;

package .tmp;

import com.jxdinfo.hussar.core.util.HussarHttpRequest;
import com.jxdinfo.hussar.core.util.PropertyUtil;
import com.jxdinfo.hussar.core.util.SecurityUtil;
import com.jxdinfo.hussar.core.util.SpringContextHolder;
import com.jxdinfo.hussar.core.util.ToolUtil;
import java.io.File;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Properties;
import org.apache.commons.lang3.StringUtils;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.cloud.client.discovery.DiscoveryClient;
import org.springframework.context.annotation.DependsOn;
import org.springframework.stereotype.Component;

@Component
@ConfigurationProperties(prefix = "hussar")
@DependsOn({"springContextHolder"})
public class HussarConfig {
  public static final String PREFIX = "hussar";
  
  @Deprecated
  private String staticVersion = "8.2.1";
  
  private Boolean swaggerOpen = Boolean.valueOf(false);
  
  private Boolean kaptchaOpen = Boolean.valueOf(false);
  
  private Boolean totpOpen = Boolean.valueOf(false);
  
  private Boolean showPoweredBy = Boolean.valueOf(true);
  
  private int totpOffsetMin = 0;
  
  private String fileUploadPathWindows = "";
  
  private String environment = "maven";
  
  private String fileUploadPathLinux = "";
  
  private String fileUploadPathMac = "";
  
  private Boolean fileDateSplit = Boolean.valueOf(true);
  
  private String firewallXssLevel = "B";
  
  private List<String> xssWhitelist = new ArrayList<>();
  
  private List<String> xssBlacklist = new ArrayList<>();
  
  private List<String> csrfWhitelist = new ArrayList<>();
  
  private List<String> referWhitelist = new ArrayList<>();
  
  private Boolean standAlone = Boolean.valueOf(true);
  
  private Boolean indexConfig = Boolean.valueOf(false);
  
  private String defaultIndex = "/default/index";
  
  private Boolean loginUpperOpen = Boolean.valueOf(false);
  
  private Boolean useSeparation = Boolean.valueOf(true);
  
  private Boolean openOrgservice = Boolean.valueOf(false);
  
  private Boolean checkCsrfOpen = Boolean.valueOf(true);
  
  private Integer remebermeDays = Integer.valueOf(7);
  
  private String volServerName = "lb://hussar-license-server";
  
  private String volServerContextPath = "/";
  
  private Boolean useVolServer = Boolean.valueOf(false);
  
  private List<String> allowHttpMethods;
  
  private List<String> ipHeaderNames;
  
  private String licFileName = null;
  
  private String licCusTitle = null;
  
  private Boolean nameIsSet = Boolean.valueOf(false);
  
  private Boolean pathIsSet = Boolean.valueOf(false);
  
  private Boolean initCheck = Boolean.valueOf(false);
  
  public String getFileUploadPath() {
    String str1 = "";
    boolean bool = getFileDateSplit().booleanValue();
    Properties properties = System.getProperties();
    String str2 = properties.getProperty("os.name");
    if (str2 != null && str2.toLowerCase().indexOf("linux") > -1) {
      str1 = this.fileUploadPathLinux;
    } else if (str2 != null && str2.toLowerCase().indexOf("windows") > -1) {
      str1 = this.fileUploadPathWindows;
    } else if (str2 != null && str2.toLowerCase().indexOf("mac") > -1) {
      str1 = this.fileUploadPathMac;
    } 
    if (ToolUtil.isEmpty(str1))
      str1 = ToolUtil.getTempPath(); 
    if (bool)
      str1 = str1 + File.separator + (new SimpleDateFormat("yyyy/MM/dd")).format(new Date()); 
    if (!str1.endsWith(File.separator))
      str1 = str1 + File.separator; 
    File file = new File(str1);
    if (!file.exists())
      file.mkdirs(); 
    return str1;
  }
  
  public String getFirewallXssLevel() {
    return this.firewallXssLevel;
  }
  
  public void setFirewallXssLevel(String paramString) {
    this.firewallXssLevel = paramString;
  }
  
  public List<String> getXssWhitelist() {
    return this.xssWhitelist;
  }
  
  public void setXssWhitelist(List<String> paramList) {
    this.xssWhitelist = paramList;
  }
  
  public void setFileUploadPathWindows(String paramString) {
    this.fileUploadPathWindows = paramString;
  }
  
  public void setFileUploadPathLinux(String paramString) {
    this.fileUploadPathLinux = paramString;
  }
  
  public String getFileUploadPathMac() {
    return this.fileUploadPathMac;
  }
  
  public void setFileUploadPathMac(String paramString) {
    this.fileUploadPathMac = paramString;
  }
  
  public Boolean getKaptchaOpen() {
    return this.kaptchaOpen;
  }
  
  public void setKaptchaOpen(Boolean paramBoolean) {
    this.kaptchaOpen = paramBoolean;
  }
  
  public Boolean getTotpOpen() {
    return this.totpOpen;
  }
  
  public void setTotpOpen(Boolean paramBoolean) {
    this.totpOpen = paramBoolean;
  }
  
  public int getTotpOffsetMin() {
    return this.totpOffsetMin;
  }
  
  public void setTotpOffsetMin(int paramInt) {
    this.totpOffsetMin = paramInt;
  }
  
  public Boolean getFileDateSplit() {
    return this.fileDateSplit;
  }
  
  public void setFileDateSplit(Boolean paramBoolean) {
    this.fileDateSplit = paramBoolean;
  }
  
  public Boolean getSwaggerOpen() {
    return this.swaggerOpen;
  }
  
  public void setSwaggerOpen(Boolean paramBoolean) {
    this.swaggerOpen = paramBoolean;
  }
  
  public boolean isStandAlone() {
    return this.standAlone.booleanValue();
  }
  
  public void setStandAlone(boolean paramBoolean) {
    this.standAlone = Boolean.valueOf(paramBoolean);
  }
  
  public boolean isIndexConfig() {
    return this.indexConfig.booleanValue();
  }
  
  public void setIndexConfig(boolean paramBoolean) {
    this.indexConfig = Boolean.valueOf(paramBoolean);
  }
  
  public String getDefaultIndex() {
    return this.defaultIndex;
  }
  
  public void setDefaultIndex(String paramString) {
    this.defaultIndex = paramString;
  }
  
  public String getStaticVersion() {
    return this.staticVersion;
  }
  
  public void setStaticVersion(String paramString) {
    this.staticVersion = paramString;
  }
  
  public String getFileUploadPathWindows() {
    return this.fileUploadPathWindows;
  }
  
  public String getFileUploadPathLinux() {
    return this.fileUploadPathLinux;
  }
  
  public Boolean getLoginUpperOpen() {
    return this.loginUpperOpen;
  }
  
  public void setLoginUpperOpen(Boolean paramBoolean) {
    this.loginUpperOpen = paramBoolean;
  }
  
  public Boolean getOpenOrgservice() {
    return this.openOrgservice;
  }
  
  public void setOpenOrgservice(Boolean paramBoolean) {
    this.openOrgservice = paramBoolean;
  }
  
  public String getEnvironment() {
    Properties properties = System.getProperties();
    String str = properties.getProperty("hussar.environment");
    if (str == null || "".equals(str))
      return this.environment; 
    return str;
  }
  
  public void setEnvironment(String paramString) {
    this.environment = paramString;
  }
  
  public List<String> getCsrfWhitelist() {
    return this.csrfWhitelist;
  }
  
  public void setCsrfWhitelist(List<String> paramList) {
    this.csrfWhitelist = paramList;
  }
  
  public List<String> getXssBlacklist() {
    return this.xssBlacklist;
  }
  
  public void setXssBlacklist(List<String> paramList) {
    this.xssBlacklist = paramList;
  }
  
  public boolean isCheckCsrfOpen() {
    return this.checkCsrfOpen.booleanValue();
  }
  
  public void setCheckCsrfOpen(boolean paramBoolean) {
    this.checkCsrfOpen = Boolean.valueOf(paramBoolean);
  }
  
  public List<String> getReferWhitelist() {
    return this.referWhitelist;
  }
  
  public void setReferWhitelist(List<String> paramList) {
    this.referWhitelist = paramList;
  }
  
  @Deprecated
  public Integer getRemebermeDays() {
    return this.remebermeDays;
  }
  
  @Deprecated
  public void setRemebermeDays(Integer paramInteger) {
    this.remebermeDays = paramInteger;
  }
  
  public Boolean getUseSeparation() {
    return this.useSeparation;
  }
  
  public void setUseSeparation(Boolean paramBoolean) {
    if (!paramBoolean.booleanValue())
      throw new RuntimeException("当前版本已不支持layui模式！请使用前后分离模式！"); 
    this.useSeparation = Boolean.valueOf(true);
  }
  
  public Boolean getUseVolServer() {
    return this.useVolServer;
  }
  
  public void setUseVolServer(Boolean paramBoolean) {
    this.useVolServer = paramBoolean;
  }
  
  public String getVolServerName() {
    return this.volServerName;
  }
  
  public void setVolServerName(String paramString) {
    if (StringUtils.startsWith(paramString, "lb://")) {
      HussarHttpRequest.volServerId = StringUtils.removeStart(paramString, "lb://");
      try {
        getClass().getClassLoader()
          .loadClass("org.springframework.cloud.client.discovery.DiscoveryClient");
      } catch (ClassNotFoundException classNotFoundException) {
        System.err.println("单体模式不支持 lb:// 格式的批量授权服务");
      } 
      HussarHttpRequest.client = (DiscoveryClient)SpringContextHolder.getBean(DiscoveryClient.class);
      PropertyUtil.setSnapMsg("vol", "hussar.vol.server", paramString);
    } else if (StringUtils.startsWithAny(paramString, new CharSequence[] { "http://", "https://" })) {
      PropertyUtil.setSnapMsg("vol", "hussar.vol.server", paramString);
    } else {
      SecurityUtil.exitSystem("授权服务器格式为：lb://hussar-license-server", true);
    } 
    this.volServerName = paramString;
    this.nameIsSet = Boolean.valueOf(true);
    if (!this.initCheck.booleanValue() && this.pathIsSet.booleanValue()) {
      SecurityUtil.getLicenseType();
      this.initCheck = Boolean.valueOf(true);
    } 
  }
  
  public List<String> getIpHeaderNames() {
    return this.ipHeaderNames;
  }
  
  public void setIpHeaderNames(List<String> paramList) {
    this.ipHeaderNames = paramList;
  }
  
  public String getVolServerContextPath() {
    return this.volServerContextPath;
  }
  
  public void setVolServerContextPath(String paramString) {
    if (StringUtils.isBlank(paramString))
      paramString = "/"; 
    HussarHttpRequest.volServerContextPath = paramString;
    this.volServerContextPath = paramString;
    this.pathIsSet = Boolean.valueOf(true);
    if (!this.initCheck.booleanValue() && this.nameIsSet.booleanValue()) {
      SecurityUtil.getLicenseType();
      this.initCheck = Boolean.valueOf(true);
    } 
  }
  
  public List<String> getAllowHttpMethods() {
    return this.allowHttpMethods;
  }
  
  public void setAllowHttpMethods(List<String> paramList) {
    this.allowHttpMethods = paramList;
  }
  
  public Boolean getShowPoweredBy() {
    return this.showPoweredBy;
  }
  
  public void setShowPoweredBy(Boolean paramBoolean) {
    this.showPoweredBy = paramBoolean;
  }
  
  public String getLicFileName() {
    return this.licFileName;
  }
  
  public void setLicFileName(String paramString) {
    this.licFileName = paramString;
  }
  
  public String getLicCusTitle() {
    return this.licCusTitle;
  }
  
  public void setLicCusTitle(String paramString) {
    this.licCusTitle = paramString;
  }
}
